#
# spec file for package freeradius-client
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           freeradius-client
Version:        1.1.7
Release:        2.1
Summary:        FreeRADIUS Client Software
License:        BSD-2-Clause
Group:          Productivity/Networking/Radius/Clients
URL:            http://www.freeradius.org/freeradius-client/
Source:         ftp://ftp.freeradius.org/pub/freeradius/%{name}-%{version}.tar.gz
Source1:        README.SUSE
Source2:        login.example
Patch0:         freeradius-client-missing_size_t_definition.patch
BuildRequires:  libnettle-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
Obsoletes:      radiusclient
Obsoletes:      radiusclient-ng
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A portable, easy-to-use and standard compliant library suitable for
developing free and commercial software that need support for a RADIUS
protocol (RFCs 2128 and 2139).

%package libs
Summary:        Shared library of FreeRADIUS Client
Group:          Productivity/Networking/Radius/Clients

%description libs
The package contains the shared library of FreeRADIUS Client

%package devel
Summary:        Header files, libraries and development documentation for freeradius-client
Group:          Productivity/Networking/Radius/Clients
Requires:       %{name}-libs = %{version}
Requires:       glibc-devel

%description devel
This package contains the header files, static libraries and
development documentation for freeradius-client. You need to install
freeradius-client-devel if you want to develop applications using
freeradius-client.

%prep
%setup -q
%patch0 -p1
find -type d -name CVS -print | xargs rm -rf
cp %{SOURCE1} .
cp %{SOURCE2} login.radius

%build
autoreconf -fiv
%configure \
    --localstatedir=%{_localstatedir}/lib \
    --enable-shadow \
    --with-nettle \
    --with-secure-path \
	--disable-static \
	--with-pic
make %{?_smp_mflags}

%install
make "DESTDIR=$RPM_BUILD_ROOT" install
rm -f %{buildroot}/%{_sbindir}/login.radius
rm -f login.radius/Makefile*
rm -f login.radius/migs/Makefile*
find %{buildroot} -type f -name "*.la" -delete -print

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc BUGS COPYRIGHT README.radexample doc/ChangeLog doc/instop.html doc/login.example
%doc login.radius README.SUSE
%dir %{_sysconfdir}/radiusclient
%{_sysconfdir}/radiusclient/dictionary
%{_sysconfdir}/radiusclient/dictionary.*
%config(noreplace) %{_sysconfdir}/radiusclient/radiusclient.conf
%config(noreplace) %{_sysconfdir}/radiusclient/issue
%config(noreplace) %{_sysconfdir}/radiusclient/port-id-map
%config(noreplace) %{_sysconfdir}/radiusclient/servers
%{_sbindir}/*

%files libs
%defattr(-, root, root)
%{_libdir}/*.so.*

%files devel
%defattr(-, root, root)
%{_libdir}/*.so
%{_includedir}/*.h

%changelog
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Apr 23 2015 vcizek@suse.com
- update to 1.1.7:
  * Allow "configure --with-nettle" to use nettle MD5 implementation. Patch from Nikos Mavrogiannopoulos.
  * Clean up generation of random numbers. Patch from Nikos Mavrogiannopoulos.
  * Update BSD license as permitted by Christos Zoulas.
  * Define PW_MAX_MSG_SIZE for maximum message sice. Patch from Nikos Mavrogiannopoulos.
  * Allow the dictionary file parser to understand BEGIN-VENDOR / END-VENDOR as with FreeRADIUS server. Patch from Nikos Mavrogiannopoulos.
  * Added support for IPv6. Patch from Nikos Mavrogiannopoulos.
  * Don't crash if a config option is unset. Patch from Nikos Mavrogiannopoulos.
  * Fix encoding of "date" attributes. Patch from Christian Schoch.
  * Build fixes from Sven Neuhaus, Ghennadi Procopciuc, Daniel Pocock, and gureedo.
  * Fix memory leaks. Patches from Alex Massover, William King, gureedo, and FreeSWITCH.
  * Fixes to retry algorithm. Patch from Lewis Adam.
  * Zero out secret fields. Patch from Scott Neugroschl.
  * Update the dictionaries. Patches from Bogdan-Andrei Iancu and gureedo.
  * Make the library thread-safe. Based on a patch from Alex Massover.
  * Made rc_avpair_log thread-safe by using a buffer supplied by the caller. Patch from Alex Massover.
  * Removed lock file for sequence number. It isn't needed.
  * Use poll() where possible to avoid issues with FD_SETSIZE. Patch from Alfred E. Heggestad.
  * Set Acct-Delay-Time in Accounting-Request packets. Patch from Alfred E. Heggestad.
- add freeradius-client-missing_size_t_definition.patch to fix
  build on 13.2
* Tue Dec  6 2011 coolo@suse.com
- BAD2c is not a license
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Feb 17 2009 prusnak@suse.cz
- fix garbled login.example file [bnc#469682]
* Wed Mar 19 2008 prusnak@suse.cz
- updated to 1.1.6
  o Added dead_time functionality / configuration
  o Merge in fixes and enhancements from 'radiusclient-ng'
  o Improved functionality for embedded operation
  - In use in FreeSWITCH and OpenSER projects
  o Wrap gethostby*() family of calls with threadsafe variants
  o Change UINT4 to uint32_t, int to size_t, etc.
  o Fixed wrong usage of strncat function in several places
- dropped obsoleted patches:
  * return.patch (included in update)
  * strncat.patch (included in update)
* Wed Mar  5 2008 crrodriguez@suse.de
- fix build in BETA
- disable static libraries
* Wed Nov  7 2007 prusnak@suse.cz
- change %%{version}-%%{release} to %%{version} in Requires tag
* Thu Mar  8 2007 prusnak@suse.cz
- created package from BuildService
  * project: network:aaa
  * package: freeradius-client
  * version: 1.1.5
